
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.033.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "A plugin for mango document model called Mandel.",
  "dist_author" => [
    "Huo Linhe <huolinhe\@berrygenomics.com>"
  ],
  "dist_name" => "Mojolicious-Plugin-Mandel",
  "dist_version" => "0.1.1",
  "license" => "perl",
  "module_name" => "Mojolicious::Plugin::Mandel",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Modern::Perl" => 0,
    "Mojo::Base" => 0,
    "Mojo::Loader" => 0
  },
  "script_files" => [],
  "test_requires" => {
    "Mandel::Document" => 0,
    "Mojolicious::Lite" => 0,
    "Test::Mojo" => 0,
    "Test::More" => 0,
    "Test::Pod" => 0,
    "Test::Pod::Coverage" => "1.00",
    "lib" => 0,
    "strict" => 0
  }
);


my %fallback_build_requires = (
  "Mandel::Document" => 0,
  "Module::Build" => "0.28",
  "Mojolicious::Lite" => 0,
  "Test::Mojo" => 0,
  "Test::More" => 0,
  "Test::Pod" => 0,
  "Test::Pod::Coverage" => "1.00",
  "lib" => 0,
  "strict" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
